import React, { useState } from 'react'
import { ChecklistItem } from '../types'

interface DateConstraintManagerProps {
  item: ChecklistItem
  onSave: (notBefore?: string, notAfter?: string) => void
  onCancel: () => void
}

export const DateConstraintManager: React.FC<DateConstraintManagerProps> = ({
  item,
  onSave,
  onCancel
}) => {
  const [notBefore, setNotBefore] = useState<string>(
    item.not_before ? new Date(item.not_before).toISOString().slice(0, 16) : ''
  )
  const [notAfter, setNotAfter] = useState<string>(
    item.not_after ? new Date(item.not_after).toISOString().slice(0, 16) : ''
  )

  const handleSave = () => {
    const notBeforeDate = notBefore ? new Date(notBefore).toISOString() : undefined
    const notAfterDate = notAfter ? new Date(notAfter).toISOString() : undefined
    onSave(notBeforeDate, notAfterDate)
  }

  const handleClear = () => {
    setNotBefore('')
    setNotAfter('')
  }

  return (
    <div className="fixed inset-0 bg-black bg-opacity-50 flex items-center justify-center z-50">
      <div className="bg-white rounded-lg p-6 w-96 max-w-full mx-4">
        <h3 className="text-lg font-semibold mb-4">Manage Date Constraints</h3>
        <p className="text-sm text-gray-600 mb-4">
          Set when this item can be completed. Leave empty to remove constraints.
        </p>
        
        <div className="space-y-4">
          <div>
            <label className="block text-sm font-medium text-gray-700 mb-1">
              Not Before (Earliest completion time)
            </label>
            <input
              type="datetime-local"
              value={notBefore}
              onChange={(e) => setNotBefore(e.target.value)}
              className="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-blue-500"
            />
          </div>
          
          <div>
            <label className="block text-sm font-medium text-gray-700 mb-1">
              Not After (Latest completion time)
            </label>
            <input
              type="datetime-local"
              value={notAfter}
              onChange={(e) => setNotAfter(e.target.value)}
              className="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-blue-500"
            />
          </div>
        </div>

        <div className="flex justify-between mt-6">
          <button
            onClick={handleClear}
            className="px-4 py-2 text-sm text-gray-600 hover:text-gray-800"
          >
            Clear All
          </button>
          <div className="space-x-2">
            <button
              onClick={onCancel}
              className="px-4 py-2 text-sm text-gray-600 hover:text-gray-800"
            >
              Cancel
            </button>
            <button
              onClick={handleSave}
              className="px-4 py-2 text-sm bg-blue-500 text-white rounded hover:bg-blue-600"
            >
              Save
            </button>
          </div>
        </div>
      </div>
    </div>
  )
} 